@@ -11,7 +11,9 @@ use constant DEBUG        => $ENV{MOJO_IRC_DEBUG}     || 0;
 use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE__), 'mojo-irc-client.crt';
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
+
+our %NUMERIC2NAME = (470 => 'ERR_LINKCHANNEL');
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -290,7 +292,7 @@ CHUNK:
 
     if ($event =~ /^\d+$/) {
       $self->emit("irc_$event" => $msg);
-      $event = IRC::Utils::numeric_to_name($event) || $event;
+      $event = $NUMERIC2NAME{$event} || IRC::Utils::numeric_to_name($event) || $event;
     }
     if ($event !~ /^\d+$/) {
       $event = lc $event;
@@ -315,7 +317,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.39
+0.40
 
 =head1 SYNOPSIS
 
