@@ -6,6 +6,8 @@ use Mojo::Util;
 
 $ENV{TEST_MOJO_IRC_SERVER_TIMEOUT} ||= $ENV{TEST_MOJO_IRC_SERVER} ? 10 : 4;
 
+has server => '';
+
 has welcome_message => <<'HERE';
 :hybrid8.local NOTICE AUTH :*** Looking up your hostname...
 :hybrid8.local NOTICE AUTH :*** Checking Ident
@@ -42,7 +44,8 @@ sub run {
 sub start_server {
   my $self = shift;
 
-  return $self->{server} if $self->{server};
+  return $self->new->tap('start_server') unless ref $self;
+  return $self->server if $self->server;
   return $ENV{TEST_MOJO_IRC_SERVER} if $ENV{TEST_MOJO_IRC_SERVER};
 
   my $port = Mojo::IOLoop::Server->generate_port;
@@ -80,14 +83,14 @@ sub start_server {
   );
 
   $self->{server_buf} = '';
-  $self->{server}     = "127.0.0.1:$port";
+  $self->server("127.0.0.1:$port")->server;
 }
 
 sub _concat_server_buf {
   my ($self, $buf) = @_;
 
   if (ref $buf eq 'ARRAY') {
-    $buf = Mojo::Loader::data_section(@$buf);
+    $buf = Mojo::Loader::data_section(@$buf == 1 ? ('main', @$buf) : @$buf);
   }
   elsif (ref $buf) {
     $buf = Mojo::Util::slurp(File::Spec->catfile(split '/', $$buf));
@@ -121,15 +124,14 @@ Test::Mojo::IRC - Module for testing Mojo::IRC
 
   use Test::Mojo::IRC -basic;
 
-  my $t      = Test::Mojo::IRC->new;
-  my $server = $t->start_server;
-  my $irc    = Mojo::IRC->new(server => $server);
+  my $t   = Test::Mojo::IRC->start_server;
+  my $irc = Mojo::IRC->new(server => $t->server);
 
   # simulate server/client communication
   $t->run(
     [
       # Send "welcome.irc" from the DATA section when client sends "NICK"
-      qr{\bNICK\b} => [ "main", "motd.irc" ],
+      qr{\bNICK\b} => [qw(main motd.irc)],
     ],
     sub {
       my $err;
@@ -168,6 +170,12 @@ of setting up a server.
 
 =head1 ATTRIBUTES
 
+=head2 server
+
+  $str = $self->server;
+
+Returns the server address, "host:port", that L</start_server> set up.
+
 =head2 welcome_message
 
   $str = $self->welcome_message;
@@ -186,7 +194,7 @@ after L</run> has completed. See L</SYNOPSIS> for example code.
 
 =head2 run
 
-  $self->run($reply_on, $cb);
+  $self->run($reply_on, sub { my $self = shift });
 
 Used to simulate communication between IRC server and client. The way this
 works is that the C<$cb> will initiate L<connect|Mojo::IRC/connect> or
@@ -211,7 +219,11 @@ Path to file on disk.
 
 =item * Array ref
 
-The module name and file passed on to L<Mojo::Loader/data_section>.
+The module name and file passed on to L<Mojo::Loader/data_section>. The default
+package is "main", meaning the two examples below is the same:
+
+  $self->run([qr{JOIN}, ["join-reply.irc"]], sub { my $self = shift });
+  $self->run([qr{JOIN}, ["main", "join-reply.irc"]], sub { my $self = shift });
 
 =back
 
@@ -224,8 +236,10 @@ See L</SYNOPSIS> for example.
 =head2 start_server
 
   $server = $self->start_server;
+  $self   = Test::Mojo::IRC->start_server;
 
-Will start a test server and return the "host:port" which it listens to.
+Will start a test server and return L</server>. It can also be called as
+a class method which will return a new object.
 
 =head2 import
 
